@@ -13,7 +13,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 Utilities for guessing MIME types of files.
@@ -37,13 +37,14 @@ where
 
 import qualified Data.Map as Map
 import qualified Control.Exception (try, IOException)
-import Control.Monad
-import System.IO
-import System.IO.Error
-import System.IO.Utils
-import System.Path
-import Data.Map.Utils
-import Data.Char
+import safe Control.Monad ( foldM )
+import safe System.IO
+    ( Handle, hClose, openFile, IOMode(ReadMode) )
+import safe System.IO.Error ()
+import safe System.IO.Utils ( hGetLines )
+import safe System.Path ( splitExt )
+import safe Data.Map.Utils ( flippedLookupM )
+import safe Data.Char ( toLower )
 
 ----------------------------------------------------------------------
 -- Basic type declarations
@@ -92,8 +93,9 @@ hReadMIMETypes :: MIMETypeData          -- ^ Data to work with
                   -> Bool               -- ^ Whether to work on strict data
                   -> Handle             -- ^ Handle to read from
                   -> IO MIMETypeData       -- ^ New object
-hReadMIMETypes mtd strict h =
-    let parseline :: MIMETypeData -> String -> MIMETypeData
+hReadMIMETypes mtd strict h = foldl parseline mtd <$> hGetLines h
+    where
+        parseline :: MIMETypeData -> String -> MIMETypeData
         parseline obj line =
             let l1 = words line
                 procwords [] = []
@@ -107,10 +109,6 @@ hReadMIMETypes mtd strict h =
                        in
                        foldl (\o suff -> addType o strict thetype ('.' : suff)) obj suffixlist
                 else obj
-        in
-          do
-            lines <- hGetLines h
-            return (foldl parseline mtd lines)
 
 {- | Guess the type of a file given a filename or URL.  The file
    is not opened; only the name is considered. -}
