@@ -1,4 +1,6 @@
 {-# LANGUAGE Safe #-}
+{-# LANGUAGE LambdaCase #-}
+{-# OPTIONS_GHC -fno-warn-name-shadowing #-}
 {- arch-tag: HVFS instance helpers
 Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
@@ -12,7 +14,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 Utilities for creating instances of the items defined in
@@ -36,11 +38,18 @@ module System.IO.HVFS.InstanceHelpers(-- * HVFSStat objects
 import           Data.IORef            (IORef, newIORef, readIORef, writeIORef)
 import           Data.List             (genericLength)
 import           System.FilePath       (isPathSeparator, pathSeparator, (</>))
-import           System.IO
+import safe System.IO ( IOMode(ReadMode) )
 import           System.IO.Error       (doesNotExistErrorType,
                                         illegalOperationErrorType,
                                         permissionErrorType)
-import           System.IO.HVFS
+import safe System.IO.HVFS
+    ( FileOffset,
+      HVFSOpenable(vOpen),
+      HVFS(vGetDirectoryContents, vGetFileStatus, vSetCurrentDirectory,
+           vRaiseError, vGetCurrentDirectory),
+      HVFSStat(vIsRegularFile, vFileSize, vIsDirectory),
+      HVFSOpenEncap(HVFSOpenEncap),
+      HVFSStatEncap(HVFSStatEncap) )
 import           System.IO.HVIO        (newStreamReader)
 import           System.Path           (absNormPath)
 import           System.Path.NameManip (slice_path)
@@ -113,10 +122,10 @@ nice_slice path
 -}
 getFullPath :: HVFS a => a -> String -> IO String
 getFullPath fs path =
-    do cwd <- vGetCurrentDirectory fs
-       case (absNormPath cwd path) of
+    do dir <- vGetCurrentDirectory fs
+       case (absNormPath dir path) of
            Nothing -> vRaiseError fs doesNotExistErrorType
-                        ("Trouble normalizing path " ++ path) (Just (cwd </> path))
+                        ("Trouble normalizing path " ++ path) (Just (dir </> path))
            Just newpath -> return newpath
 
 {- | Gets the full path via 'getFullPath', then splits it via 'nice_slice'.
@@ -183,8 +192,7 @@ instance HVFS MemoryVFS where
                                               "Bad internal error" (Just fp)
                        Just y -> writeIORef (cwd x) y
     vGetFileStatus x fp =
-        do elem <- getMelem x fp
-           case elem of
+        getMelem x fp >>= \case
                      (MemoryFile y) -> return $ HVFSStatEncap $
                                              SimpleStat {isFile = True,
                                                         fileSize = (genericLength y)}
@@ -192,8 +200,7 @@ instance HVFS MemoryVFS where
                                              SimpleStat {isFile = False,
                                                         fileSize = 0}
     vGetDirectoryContents x fp =
-        do elem <- getMelem x fp
-           case elem of
+        getMelem x fp >>= \case
                 MemoryFile _ -> vRaiseError x doesNotExistErrorType
                                   "Can't list contents of a file"
                                   (Just fp)
@@ -201,8 +208,7 @@ instance HVFS MemoryVFS where
 
 instance HVFSOpenable MemoryVFS where
     vOpen x fp (ReadMode) =
-        do elem <- getMelem x fp
-           case elem of
+        getMelem x fp >>= \case
                 MemoryDirectory _ -> vRaiseError x doesNotExistErrorType
                                       "Can't open a directory"
                                       (Just fp)
@@ -210,4 +216,3 @@ instance HVFSOpenable MemoryVFS where
     vOpen x fp _ = vRaiseError x permissionErrorType
                      "Only ReadMode is supported with MemoryVFS files"
                      (Just fp)
-
