@@ -13,7 +13,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 This module provides various helpful utilities for dealing with path and
@@ -31,21 +31,23 @@ module System.Path(-- * Name processing
                      mktmpdir, brackettmpdir, brackettmpdirCWD
                     )
 where
-import           Data.List
-import           Data.List.Utils
+import safe Data.List.Utils ( startswith, alwaysElemRIndex )
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-import           System.Directory       hiding (createDirectory)
-import           System.Posix.Directory (createDirectory)
-import           System.Posix.Files
-import           System.Posix.Temp
+import safe System.Directory
+    ( getCurrentDirectory, removeFile, setCurrentDirectory )
+import safe System.Posix.Directory ( createDirectory )
+import safe System.Posix.Temp ( mkstemp )
 #else
-import           System.Directory
+import safe System.Directory
+import safe System.IO ( openTempFile )
 #endif
-import           Control.Exception
-import           System.FilePath        (isPathSeparator, pathSeparator, (</>))
-import           System.IO
-import           System.IO.HVFS.Utils
-import           System.Path.NameManip
+import safe Control.Exception ( finally )
+import safe System.FilePath ( pathSeparator )
+import safe System.IO ( hClose )
+import safe System.IO.HVFS.Utils
+    ( SystemFS(SystemFS), recurseDir, recurseDirStat, recursiveRemove )
+import safe System.Path.NameManip
+    ( normalise_path, absolute_path_by, guess_dotdot )
 
 {- | Splits a pathname into a tuple representing the root of the name and
 the extension.  The extension is considered to be all characters from the last
@@ -76,8 +78,8 @@ absNormPath :: String                   -- ^ Absolute path for use with starting
             -> String                   -- ^ The path name to make absolute
             -> Maybe String                   -- ^ Result
 absNormPath base thepath =
-    let abs = absolute_path_by base thepath
-        in case guess_dotdot (normalise_path abs) of
+    let path = absolute_path_by base thepath
+        in case guess_dotdot (normalise_path path) of
                 Just "." -> Just [pathSeparator]
                 x        -> x
 
