@@ -12,7 +12,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 Written by John Goerzen, jgoerzen\@complete.org
@@ -29,7 +29,16 @@ module Text.ParserCombinators.Parsec.Utils(-- * Generalized Utilities
                        notMatching
                       ) where
 
-import           Text.ParserCombinators.Parsec
+import safe Text.ParserCombinators.Parsec
+    ( (<?>),
+      (<|>),
+      getPosition,
+      many,
+      token,
+      unexpected,
+      try,
+      SourcePos,
+      GenParser )
 
 type GeneralizedToken a = (SourcePos, a)
 type GeneralizedTokenParser a st b = GenParser (GeneralizedToken a) st b
@@ -98,4 +107,3 @@ notMatching p errormsg =
                              Just _  -> unexpected errormsg
         in
         try workerFunc
-
